package com.caimei365.manager.controller;

import com.caimei365.manager.config.security.ConstantKey;
import com.caimei365.manager.config.security.JwtService;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.wechat.WechatMenu;
import com.caimei365.manager.service.WeChatService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 微信后台管理
 *
 * @author : Charles
 * @date : 2022/1/4
 */
@RestController
@RequestMapping("/wechat")
public class WeChatApi {

    @Resource
    private WeChatService weChatService;
    @Resource
    private JwtService jwtService;

    /**
     * 获取微信公众号菜单列表
     *
     * @param type 类型： 1采美，2呵呵商城
     */
    @GetMapping("/menu/list")
    public ResponseJson<List<WechatMenu>> wechatMenuList(Integer type) {
        return weChatService.getWechatMenuList(type);
    }

    /**
     * 根据ID获取微信公众号菜单
     */
    @GetMapping("/menu/{id}")
    public ResponseJson<WechatMenu> getWechatMenu(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        return weChatService.getWechatMenu(id);
    }

    /**
     * 根据ID更新微信公众号菜单
     */
    @PostMapping("/menu/update/{id}")
    public ResponseJson<Void> updateWechatMenu(HttpServletRequest request, @PathVariable("id") Integer id, @RequestBody WechatMenu menu) {
        if (null == id || id <= 0) {
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return weChatService.updateWechatMenu(id, menu, username);
    }

    /**
     * 添加微信公众号菜单
     */
    @PostMapping("/menu/create")
    public ResponseJson<Void> addWechatMenu(HttpServletRequest request, @RequestBody WechatMenu menu) {
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return weChatService.addWechatMenu(menu, username);
    }

    /**
     * 根据ID删除微信公众号菜单
     */
    @PostMapping("/menu/delete/{id}")
    public ResponseJson<Void> deleteWechatMenu(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        return weChatService.deleteWechatMenu(id);
    }

    /**
     * 微信公众号菜单发布
     * @param type 类型： 1采美，2呵呵商城
     */
    @PostMapping("/menu/push/{type}")
    public ResponseJson<Void> pushWechatMenu(@PathVariable("type") Integer type) {
        return weChatService.pushWechatMenu(type);
    }
}
